@@ -114,6 +114,7 @@ ASSERT
 AUTO_INCREMENT
 BEGIN
 BERNOULLI
+BI_CAPACITY
 BINARY
 BINDING
 BREAK
@@ -218,6 +219,7 @@ OPERATE
 OPTION
 OPTIONS
 ORDINAL
+ORGANIZATION
 OUT
 OVERLAPS
 OVERWRITE
@@ -230,6 +232,7 @@ PRIMARY
 PRIOR
 PRIVILEGES
 PROCEDURE
+PROJECT
 PUBLIC
 QUALIFY
 QUARTER
