@@ -195,6 +195,14 @@ mysql_dialect.replace(
             Ref("VariableAssignmentSegment"),
         ]
     ),
+    Expression_D_Potential_Select_Statement_Without_Brackets=ansi_dialect.get_grammar(
+        "Expression_D_Potential_Select_Statement_Without_Brackets"
+    ).copy(
+        insert=[
+            Ref("SessionVariableNameSegment"),
+        ],
+        at=0,
+    ),
     ArithmeticBinaryOperatorGrammar=ansi_dialect.get_grammar(
         "ArithmeticBinaryOperatorGrammar"
     ).copy(
@@ -280,6 +288,7 @@ mysql_dialect.replace(
             anti_template=r"^(" + r"|".join(dialect.sets("reserved_keywords")) + r")$",
         )
     ),
+    LikeGrammar=OneOf("LIKE", "RLIKE", "REGEXP"),
 )
 
 mysql_dialect.add(
@@ -398,14 +407,209 @@ class CreateTableStatementSegment(ansi.CreateTableStatementSegment):
     https://dev.mysql.com/doc/refman/8.0/en/create-table.html
     """
 
+    ES = Ref("ExpressionSegment")
+    CRS = Ref("ColumnReferenceSegment")
+    NLS = Ref("NumericLiteralSegment")
+    ORS = Ref("ObjectReferenceSegment")
+    TRS = Ref("TableReferenceSegment")
+    SQIS = Ref("SingleQuotedIdentifierSegment")
+
     match_grammar = ansi.CreateTableStatementSegment.match_grammar.copy(
         insert=[
             AnyNumberOf(
                 Sequence(
                     Ref.keyword("DEFAULT", optional=True),
-                    Ref("ParameterNameSegment"),
+                    OneOf(
+                        Ref("ParameterNameSegment"),
+                        Sequence("CHARACTER", "SET"),
+                        Sequence(OneOf("DATA", "INDEX"), "DIRECTORY"),
+                        Sequence("WITH", "SYSTEM"),
+                    ),
                     Ref("EqualsSegment", optional=True),
-                    OneOf(Ref("LiteralGrammar"), Ref("ParameterNameSegment")),
+                    OneOf(
+                        Ref("LiteralGrammar"),
+                        Ref("ParameterNameSegment"),
+                        Ref("QuotedLiteralSegment"),
+                        Ref("SingleQuotedIdentifierSegment"),
+                        Ref("NumericLiteralSegment"),
+                        # Union option
+                        Bracketed(
+                            Delimited(Ref("TableReferenceSegment")),
+                        ),
+                    ),
+                ),
+                # Partition Options
+                # https://dev.mysql.com/doc/refman/8.0/en/create-table.html#create-table-partitioning
+                Sequence(
+                    "PARTITION",
+                    "BY",
+                    OneOf(
+                        Sequence(
+                            Ref.keyword("LINEAR", optional=True),
+                            OneOf(
+                                Sequence("HASH", Ref("ExpressionSegment")),
+                                Sequence(
+                                    "KEY",
+                                    Sequence(
+                                        "ALGORITHM",
+                                        Ref("EqualsSegment"),
+                                        Ref("NumericLiteralSegment"),
+                                        optional=True,
+                                    ),
+                                    Delimited(Ref("ColumnReferenceSegment")),
+                                ),
+                            ),
+                        ),
+                        Sequence(
+                            OneOf("RANGE", "LIST"),
+                            OneOf(
+                                Ref("ExpressionSegment"),
+                                Bracketed(Delimited(Ref("ColumnReferenceSegment"))),
+                            ),
+                        ),
+                    ),
+                    Sequence("PARTITIONS", Ref("NumericLiteralSegment"), optional=True),
+                    Sequence(
+                        "SUBPARTITION",
+                        "BY",
+                        Sequence(
+                            Ref.keyword("LINEAR", optional=True),
+                            OneOf(
+                                Sequence("HASH", Ref("ExpressionSegment")),
+                                Sequence(
+                                    "KEY",
+                                    Sequence(
+                                        "ALGORITHM",
+                                        Ref("EqualsSegment"),
+                                        Ref("NumericLiteralSegment"),
+                                        optional=True,
+                                    ),
+                                    Bracketed(Ref("ColumnReferenceSegment")),
+                                ),
+                            ),
+                        ),
+                        Sequence(
+                            "SUBPARTITIONS",
+                            Ref("NumericLiteralSegment"),
+                            optional=True,
+                        ),
+                        optional=True,
+                    ),
+                    # optional partition_definition(s)
+                    AnyNumberOf(
+                        Bracketed(
+                            Delimited(
+                                Sequence(
+                                    "PARTITION",
+                                    Ref("ColumnReferenceSegment"),
+                                    AnyNumberOf(
+                                        Sequence(
+                                            "VALUES",
+                                            OneOf(
+                                                Sequence(
+                                                    "LESS",
+                                                    "THAN",
+                                                    OneOf(
+                                                        "MAXVALUE",
+                                                        Bracketed(
+                                                            OneOf(
+                                                                ES,
+                                                                CRS,
+                                                                NLS,
+                                                                Ref("LiteralGrammar"),
+                                                            ),
+                                                        ),
+                                                    ),
+                                                ),
+                                                Sequence(
+                                                    "IN",
+                                                    Bracketed(
+                                                        Ref("ObjectReferenceSegment")
+                                                    ),
+                                                ),
+                                            ),
+                                        ),
+                                        Sequence(
+                                            OneOf(
+                                                Ref("ParameterNameSegment"),
+                                                Sequence("CHARACTER", "SET"),
+                                                Sequence(
+                                                    OneOf("DATA", "INDEX"),
+                                                    "DIRECTORY",
+                                                ),
+                                                Sequence("WITH", "SYSTEM"),
+                                            ),
+                                            Ref("EqualsSegment", optional=True),
+                                            OneOf(
+                                                Ref("LiteralGrammar"),
+                                                Ref("ParameterNameSegment"),
+                                                Ref("QuotedLiteralSegment"),
+                                                Ref("SingleQuotedIdentifierSegment"),
+                                                Ref("NumericLiteralSegment"),
+                                                # Union option
+                                                Bracketed(
+                                                    Delimited(
+                                                        Ref("TableReferenceSegment")
+                                                    ),
+                                                ),
+                                            ),
+                                        ),
+                                        # optional subpartition_definition(s)
+                                        Sequence(
+                                            Ref.keyword("SUBPARTITION", optional=True),
+                                            Ref("LiteralGrammar"),
+                                            AnyNumberOf(
+                                                Sequence(
+                                                    "VALUES",
+                                                    OneOf(
+                                                        Sequence(
+                                                            "LESS",
+                                                            "THAN",
+                                                            OneOf(
+                                                                "MAXVALUE",
+                                                                Bracketed(ES),
+                                                                Bracketed(CRS),
+                                                            ),
+                                                        ),
+                                                        Sequence(
+                                                            "IN",
+                                                            Bracketed(ORS),
+                                                        ),
+                                                    ),
+                                                ),
+                                                Sequence(
+                                                    OneOf(
+                                                        Ref("ParameterNameSegment"),
+                                                        Sequence("CHARACTER", "SET"),
+                                                        Sequence(
+                                                            OneOf("DATA", "INDEX"),
+                                                            "DIRECTORY",
+                                                        ),
+                                                        Sequence("WITH", "SYSTEM"),
+                                                    ),
+                                                    Ref(
+                                                        "EqualsSegment",
+                                                        optional=True,
+                                                    ),
+                                                    OneOf(
+                                                        Ref("LiteralGrammar"),
+                                                        Ref("ParameterNameSegment"),
+                                                        Ref("QuotedLiteralSegment"),
+                                                        SQIS,
+                                                        Ref("NumericLiteralSegment"),
+                                                        # Union option
+                                                        Bracketed(
+                                                            Delimited(TRS),
+                                                        ),
+                                                    ),
+                                                ),
+                                            ),
+                                        ),
+                                    ),
+                                ),
+                            ),
+                        ),
+                    ),
                 ),
             ),
         ],
@@ -723,6 +927,12 @@ class ColumnConstraintSegment(ansi.ColumnConstraintSegment):
         ansi.ColumnConstraintSegment.match_grammar,
         Sequence("CHARACTER", "SET", Ref("NakedIdentifierSegment")),
         Sequence("COLLATE", Ref("CollationReferenceSegment")),
+        Sequence(
+            Sequence("GENERATED", "ALWAYS", optional=True),
+            "AS",
+            Bracketed(Ref("ExpressionSegment")),
+            OneOf("STORED", "VIRTUAL", optional=True),
+        ),  # https://www.sqlite.org/gencol.html
     )
 
 
