@@ -82,8 +82,8 @@ TRIGGER
 TRY_CAST
 UNION
 UNIQUE
-UPDATE
 UNPIVOT
+UPDATE
 USING
 VALUES
 WHEN
@@ -106,6 +106,7 @@ ALLOWED_VALUES
 ALLOW_DUPLICATE
 ALLOW_OVERLAPPING_EXECUTION
 ALLOW_WRITES
+ALWAYS
 API
 API_INTEGRATION
 APPEND_ONLY
@@ -202,6 +203,7 @@ CURRENT_VERSION
 CURRENT_WAREHOUSE
 CURSOR
 CYCLE
+DAILY
 DATA
 DATABASE
 DATABASES
@@ -209,8 +211,8 @@ DATA_FORMAT
 DATA_RETENTION_TIME_IN_DAYS
 DATE
 DATE_FORMAT
-DAILY
 DAYS_TO_EXPIRY
+DEBUG
 DEFAULT
 DEFAULT_DDL_COLLATION
 DEFAULT_NAMESPACE
@@ -250,10 +252,12 @@ END_TIMESTAMP
 ENFORCED
 ENFORCE_LENGTH
 ENUM
+ERROR
 ERROR_INTEGRATION
 ERROR_ON_COLUMN_COUNT_MISMATCH
 ESCAPE
 ESCAPE_UNENCLOSED_FIELD
+EVENT
 EXCEPT
 EXCHANGE
 EXCLUDE
@@ -262,9 +266,12 @@ EXECUTION
 EXPLAIN
 EXTENSION
 EXTERNAL
+EXTERNAL_ACCESS_INTEGRATIONS
 EXTERNAL_STAGE
+FATAL
 FETCH
 FIELD_DELIMITER
+FIELD_OPTIONALITY_ENCLOSED_BY
 FIELD_OPTIONALLY_ENCLOSED_BY
 FILE
 FILES
@@ -308,13 +315,15 @@ IMMEDIATE
 IMMEDIATELY
 IMMUTABLE
 IMPORT
-IMPORTS
 IMPORTED
+IMPORTS
+INCLUDE
 INCLUDE_QUERY_ID
 INDEX
+INFO
 INFORMATION
-INITIALLY
 INITIALIZE
+INITIALLY
 INITIALLY_SUSPENDED
 INPUT
 INTEGRATION
@@ -340,6 +349,7 @@ LOCAL
 LOCATION
 LOCKS
 LOGIN_NAME
+LOG_LEVEL
 LS
 LZO
 M
@@ -377,9 +387,9 @@ MUST_CHANGE_PASSWORD
 NAME
 NAN
 NETWORK
+NEVER
 NEXT
 NEXTVAL
-NEVER
 NO
 NOCACHE
 NOCYCLE
@@ -394,11 +404,13 @@ NULLS
 NULL_IF
 OBJECT
 OBJECTS
+OFF
 OFFSET
 OMIT
 ONE
 ONLY
 ON_ERROR
+ON_EVENT
 OPERATE
 OPTIMIZATION
 OPTION
@@ -421,7 +433,6 @@ PARTITION
 PASSWORD
 PAST
 PATTERN
-FIELD_OPTIONALITY_ENCLOSED_BY
 PER
 PERCENT
 PERMUTE
@@ -502,6 +513,7 @@ SCHEMA
 SCHEMAS
 SEARCH
 SECONDARY
+SECRETS
 SECURE
 SECURITY
 SEED
@@ -552,17 +564,17 @@ STORAGE_LOCATION
 STORAGE_LOCATIONS
 STORAGE_PROVIDER
 STREAM
-STREAMS
 STREAMLIT
 STREAMLITS
+STREAMS
 STRIP_NULL_VALUES
 STRIP_OUTER_ARRAY
 STRIP_OUTER_ELEMENT
 SUBPATH
 SUPPORT
 SUSPEND
-SUSPEND_IMMEDIATE
 SUSPENDED
+SUSPEND_IMMEDIATE
 SWAP
 SYSDATE
 SYSTEM
@@ -570,8 +582,8 @@ TABLES
 TABLESPACE
 TABULAR
 TAG
-TARGET_PATH
 TARGET_LAG
+TARGET_PATH
 TASK
 TASKS
 TEMP
@@ -584,11 +596,13 @@ TIMESTAMP
 TIMESTAMP_FORMAT
 TIME_FORMAT
 TOP
+TRACE
+TRACE_LEVEL
 TRANSACTION
 TRANSACTIONS
 TRANSIENT
-TRIM_SPACE
 TRIGGERS
+TRIM_SPACE
 TRUNCATE
 TRUNCATECOLUMNS
 TYPE
@@ -624,6 +638,7 @@ WAREHOUSE
 WAREHOUSES
 WAREHOUSE_SIZE
 WAREHOUSE_TYPE
+WARN
 WEEKLY
 WINDOW
 WITH
