@@ -23,6 +23,9 @@ from sqlfluff.core.parser import (
     Ref,
     RegexLexer,
     Sequence,
+    StringLexer,
+    StringParser,
+    SymbolSegment,
     TypedParser,
     WhitespaceSegment,
 )
@@ -89,6 +92,44 @@ sqlite_dialect.patch_lexer_matchers(
     ]
 )
 
+sqlite_dialect.insert_lexer_matchers(
+    [
+        RegexLexer(
+            "at_sign_literal",
+            r"@[a-zA-Z0-9_]+",
+            LiteralSegment,
+            segment_kwargs={"type": "at_sign_literal"},
+        ),
+        RegexLexer(
+            "colon_literal",
+            r":[a-zA-Z0-9_]+",
+            LiteralSegment,
+            segment_kwargs={"type": "colon_literal"},
+        ),
+        RegexLexer(
+            "question_literal",
+            r"\?[0-9]+",
+            LiteralSegment,
+            segment_kwargs={"type": "question_literal"},
+        ),
+        RegexLexer(
+            "dollar_literal",
+            r"\$[a-zA-Z0-9_]+",
+            LiteralSegment,
+            segment_kwargs={"type": "dollar_literal"},
+        ),
+    ],
+    before="question",
+)
+
+sqlite_dialect.insert_lexer_matchers(
+    [
+        StringLexer("inline_path_operator", "->>", CodeSegment),
+        StringLexer("column_path_operator", "->", CodeSegment),
+    ],
+    before="greater_than",
+)
+
 sqlite_dialect.add(
     BackQuotedIdentifierSegment=TypedParser(
         "back_quote",
@@ -97,6 +138,33 @@ sqlite_dialect.add(
         # match ANSI's naked identifier casefold, sqlite is case-insensitive.
         casefold=str.upper,
     ),
+    ColumnPathOperatorSegment=StringParser(
+        "->", SymbolSegment, type="column_path_operator"
+    ),
+    InlinePathOperatorSegment=StringParser(
+        "->>", SymbolSegment, type="column_path_operator"
+    ),
+    QuestionMarkSegment=StringParser("?", SymbolSegment, type="question_mark"),
+    AtSignLiteralSegment=TypedParser(
+        "at_sign_literal",
+        LiteralSegment,
+        type="at_sign_literal",
+    ),
+    ColonLiteralSegment=TypedParser(
+        "colon_literal",
+        LiteralSegment,
+        type="colon_literal",
+    ),
+    QuestionLiteralSegment=TypedParser(
+        "question_literal",
+        LiteralSegment,
+        type="question_literal",
+    ),
+    DollarLiteralSegment=TypedParser(
+        "dollar_literal",
+        LiteralSegment,
+        type="dollar_literal",
+    ),
 )
 
 sqlite_dialect.replace(
@@ -107,6 +175,13 @@ sqlite_dialect.replace(
         Ref("ConflictClauseSegment", optional=True),
         Sequence("AUTOINCREMENT", optional=True),
     ),
+    NumericLiteralSegment=OneOf(
+        TypedParser("numeric_literal", LiteralSegment, type="numeric_literal"),
+        Ref("ParameterizedSegment"),
+    ),
+    LiteralGrammar=ansi_dialect.get_grammar("LiteralGrammar").copy(
+        insert=[Ref("ParameterizedSegment")]
+    ),
     TemporaryTransientGrammar=Ref("TemporaryGrammar"),
     DateTimeLiteralGrammar=Sequence(
         OneOf("DATE", "DATETIME"),
@@ -182,7 +257,10 @@ sqlite_dialect.replace(
         "HAVING",
         "WINDOW",
     ),
-    PostFunctionGrammar=Ref("FilterClauseGrammar"),
+    PostFunctionGrammar=Sequence(
+        Ref("FilterClauseGrammar", optional=True),
+        Ref("OverClauseSegment", optional=True),
+    ),
     IgnoreRespectNullsGrammar=Nothing(),
     SelectClauseTerminatorGrammar=OneOf(
         "FROM",
@@ -273,9 +351,68 @@ sqlite_dialect.replace(
         "single_quote", IdentifierSegment, type="quoted_identifier", casefold=str.upper
     ),
     ColumnConstraintDefaultGrammar=Ref("ExpressionSegment"),
+    FrameClauseUnitGrammar=OneOf("ROWS", "RANGE", "GROUPS"),
 )
 
 
+class FrameClauseSegment(BaseSegment):
+    """A frame clause for window functions.
+
+    https://www.sqlite.org/syntax/frame-spec.html
+    """
+
+    type = "frame_clause"
+
+    match_grammar: Matchable = Sequence(
+        Ref("FrameClauseUnitGrammar"),
+        OneOf(
+            Sequence("UNBOUNDED", "PRECEDING"),
+            Sequence("CURRENT", "ROW"),
+            Sequence(Ref("ExpressionSegment"), "PRECEDING"),
+            Sequence(
+                "BETWEEN",
+                OneOf(
+                    Sequence("UNBOUNDED", "PRECEDING"),
+                    Sequence("CURRENT", "ROW"),
+                    Sequence(Ref("ExpressionSegment"), "FOLLOWING"),
+                    Sequence(Ref("ExpressionSegment"), "PRECEDING"),
+                ),
+                "AND",
+                OneOf(
+                    Sequence("UNBOUNDED", "FOLLOWING"),
+                    Sequence("CURRENT", "ROW"),
+                    Sequence(Ref("ExpressionSegment"), "FOLLOWING"),
+                    Sequence(Ref("ExpressionSegment"), "PRECEDING"),
+                ),
+            ),
+        ),
+        Sequence(
+            "EXCLUDE",
+            OneOf(
+                Sequence("NO", "OTHERS"), Sequence("CURRENT", "ROW"), "TIES", "GROUP"
+            ),
+            optional=True,
+        ),
+    )
+
+
+class ParameterizedSegment(BaseSegment):
+    """Sqlite allows named and argument based parameters to prevent SQL Injection.
+
+    https://www.sqlite.org/c3ref/bind_blob.html
+
+    """
+
+    type = "parameterized_expression"
+    match_grammar = OneOf(
+        Ref("AtSignLiteralSegment"),
+        Ref("QuestionMarkSegment"),
+        Ref("ColonLiteralSegment"),
+        Ref("QuestionLiteralSegment"),
+        Ref("DollarLiteralSegment"),
+    )
+
+
 class SetOperatorSegment(BaseSegment):
     """A set operator such as Union, Minus, Except or Intersect."""
 
@@ -293,6 +430,62 @@ class SetOperatorSegment(BaseSegment):
     )
 
 
+class ColumnReferenceSegment(ansi.ColumnReferenceSegment):
+    """A reference to column, field or alias.
+
+    Also allows `column->path` and `column->>path` for JSON values.
+    https://www.sqlite.org/json1.html#jptr
+    """
+
+    match_grammar = ansi.ColumnReferenceSegment.match_grammar.copy(
+        insert=[
+            Sequence(
+                OneOf(
+                    ansi.ColumnReferenceSegment.match_grammar.copy(),
+                    Ref("FunctionSegment"),
+                    Ref("BareFunctionSegment"),
+                    Ref("LiteralGrammar"),
+                ),
+                AnyNumberOf(
+                    Sequence(
+                        OneOf(
+                            Ref("ColumnPathOperatorSegment"),
+                            Ref("InlinePathOperatorSegment"),
+                        ),
+                        OneOf(
+                            Ref("LiteralGrammar"),
+                            Ref("QuotedIdentifierSegment"),
+                        ),
+                    )
+                ),
+            ),
+        ]
+    )
+
+
+class TableReferenceSegment(ansi.TableReferenceSegment):
+    """A reference to a table.
+
+    Also allows `table->path` and `table->>path` for JSON values.
+    https://www.sqlite.org/json1.html#jptr
+    """
+
+    match_grammar = ansi.TableReferenceSegment.match_grammar.copy(
+        insert=[
+            Sequence(
+                ansi.TableReferenceSegment.match_grammar.copy(),
+                OneOf(
+                    Ref("ColumnPathOperatorSegment"),
+                    Ref("InlinePathOperatorSegment"),
+                ),
+                OneOf(
+                    Ref("LiteralGrammar"),
+                ),
+            ),
+        ]
+    )
+
+
 class DatatypeSegment(ansi.DatatypeSegment):
     """A data type segment.
 
@@ -702,6 +895,24 @@ class CreateTriggerStatementSegment(ansi.CreateTriggerStatementSegment):
     )
 
 
+class CreateViewStatementSegment(BaseSegment):
+    """A `CREATE VIEW` statement."""
+
+    type = "create_view_statement"
+    # https://www.sqlite.org/lang_createview.html
+    match_grammar: Matchable = Sequence(
+        "CREATE",
+        Ref("TemporaryGrammar", optional=True),
+        "VIEW",
+        Ref("IfNotExistsGrammar", optional=True),
+        Ref("TableReferenceSegment"),
+        # Optional list of column names
+        Ref("BracketedColumnReferenceListGrammar", optional=True),
+        "AS",
+        OptionallyBracketed(Ref("SelectableGrammar")),
+    )
+
+
 class UnorderedSelectStatementSegment(BaseSegment):
     """A `SELECT` statement without any ORDER clauses or later.
 
@@ -747,11 +958,30 @@ class UpdateStatementSegment(ansi.UpdateStatementSegment):
     type = "update_statement"
     match_grammar: Matchable = Sequence(
         "UPDATE",
+        Sequence(
+            "OR",
+            OneOf(
+                "ABORT",
+                "FAIL",
+                "IGNORE",
+                "REPLACE",
+                "ROLLBACK",
+            ),
+            optional=True,
+        ),
         Ref("TableReferenceSegment"),
-        # SET is not a reserved word in all dialects (e.g. RedShift)
-        # So specifically exclude as an allowed implicit alias to avoid parsing errors
-        Ref("AliasExpressionSegment", exclude=Ref.keyword("SET"), optional=True),
-        Ref("SetClauseListSegment"),
+        Ref("AliasExpressionSegment", optional=True),
+        "SET",
+        Delimited(
+            Sequence(
+                OneOf(
+                    Ref("SingleIdentifierGrammar"),
+                    Ref("BracketedColumnReferenceListGrammar"),
+                ),
+                Ref("EqualsSegment"),
+                Ref("ExpressionSegment"),
+            ),
+        ),
         Ref("FromClauseSegment", optional=True),
         Ref("WhereClauseSegment", optional=True),
         Ref("ReturningClauseSegment", optional=True),
